<?php

namespace SGalinski\SgNews\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (http://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Domain\Model\FileReference;
use TYPO3\CMS\Extbase\DomainObject\AbstractEntity;
use TYPO3\CMS\Extbase\Persistence\Generic\LazyLoadingProxy;
use TYPO3\CMS\Extbase\Persistence\ObjectStorage;

/**
 * Abstract Category and news
 */
abstract class CategoryAndNews extends AbstractEntity {
	/**
	 * @var string
	 */
	protected $teaser1Coordinates = '';

	/**
	 * @var string
	 */
	protected $teaser2Coordinates = '';

	/**
	 * @var int
	 */
	protected $teaser1HeaderColor = 0;

	/**
	 * @var int
	 */
	protected $teaser2HeaderColor = 0;

	/**
	 * @var boolean
	 */
	protected $useImageCrop = FALSE;

	/**
	 * @var boolean
	 */
	protected $useImage2Crop = FALSE;

	/**
	 * @var string
	 */
	protected $navTitle = '';

	/**
	 * @var string
	 */
	protected $title = '';

	/**
	 * @var string
	 */
	protected $subtitle = '';

	/**
	 * @var int
	 */
	protected $sorting = 0;

	/**
	 * @lazy
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\TYPO3\CMS\Extbase\Domain\Model\FileReference>
	 */
	protected $teaser1Image;

	/**
	 * @lazy
	 * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\TYPO3\CMS\Extbase\Domain\Model\FileReference>
	 */
	protected $teaser2Image;

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->teaser1Image = new ObjectStorage();
		$this->teaser2Image = new ObjectStorage();
	}

	/**
	 * @param string $title
	 * @return void
	 */
	public function setTitle($title) {
		$this->title = $title;
	}

	/**
	 * @return string
	 */
	public function getTitle() {
		return $this->title;
	}

	/**
	 * @param string $navTitle
	 * @return void
	 */
	public function setNavTitle($navTitle) {
		$this->navTitle = $navTitle;
	}

	/**
	 * @return string
	 */
	public function getNavTitle() {
		return $this->navTitle;
	}

	/**
	 * @param string $subtitle
	 * @return void
	 */
	public function setSubtitle($subtitle) {
		$this->subtitle = $subtitle;
	}

	/**
	 * @return string
	 */
	public function getSubtitle() {
		return $this->subtitle;
	}

	/**
	 * @return string
	 */
	public function getSubtitleWithFallbackToTitle() {
		return ($this->subtitle !== '' ? $this->subtitle : $this->title);
	}

	/**
	 * Teaser1Coordinates is an comma separated list like this: 1,2,3,4...
	 *
	 * @param array $teaser1Coordinates
	 * @return void
	 */
	public function setTeaser1Coordinates(array $teaser1Coordinates) {
		$this->teaser1Coordinates = implode(',', $teaser1Coordinates);
	}

	/**
	 * Returning array structure:
	 * array (
	 *        'x1' => string,
	 *        'y1' => string,
	 *        'x2' => string,
	 *        'y2' => string,
	 *        'w' => string,
	 *        'h' => string,
	 * )
	 *
	 * @return array
	 */
	public function getTeaser1Coordinates() {
		$mappedCoordinates = [];
		$explodedCoordinates = GeneralUtility::intExplode(',', $this->teaser1Coordinates);
		if (count($explodedCoordinates) === 6) {
			$mappedCoordinates = [
				'x1' => $explodedCoordinates[0],
				'y1' => $explodedCoordinates[1],
				'x2' => $explodedCoordinates[2],
				'y2' => $explodedCoordinates[3],
				'w' => $explodedCoordinates[4],
				'h' => $explodedCoordinates[5],
			];
		}

		return $mappedCoordinates;
	}

	/**
	 * Teaser2Coordinates is an comma separated list like this: 1,2,3,4...
	 *
	 * @param array $teaser2Coordinates
	 * @return void
	 */
	public function setTeaser2Coordinates(array $teaser2Coordinates) {
		$this->teaser2Coordinates = implode(',', $teaser2Coordinates);
	}

	/**
	 * Returning array structure:
	 * array (
	 *        'x1' => string,
	 *        'y1' => string,
	 *        'x2' => string,
	 *        'y2' => string,
	 *        'w' => string,
	 *        'h' => string,
	 * )
	 *
	 * @return array
	 */
	public function getTeaser2Coordinates() {
		$mappedCoordinates = [];
		$explodedCoordinates = GeneralUtility::intExplode(',', $this->teaser2Coordinates);
		if (count($explodedCoordinates) === 6) {
			$mappedCoordinates = [
				'x1' => $explodedCoordinates[0],
				'y1' => $explodedCoordinates[1],
				'x2' => $explodedCoordinates[2],
				'y2' => $explodedCoordinates[3],
				'w' => $explodedCoordinates[4],
				'h' => $explodedCoordinates[5],
			];
		}

		return $mappedCoordinates;
	}

	/**
	 * @param int $teaser1HeaderColor
	 * @return void
	 */
	public function setTeaser1HeaderColor($teaser1HeaderColor) {
		$this->teaser1HeaderColor = (int) $teaser1HeaderColor;
	}

	/**
	 * @return int
	 */
	public function getTeaser1HeaderColor() {
		return $this->teaser1HeaderColor;
	}

	/**
	 * @param int $teaser2HeaderColor
	 * @return void
	 */
	public function setTeaser2HeaderColor($teaser2HeaderColor) {
		$this->teaser2HeaderColor = (int) $teaser2HeaderColor;
	}

	/**
	 * @return int
	 */
	public function getTeaser2HeaderColor() {
		return $this->teaser2HeaderColor;
	}

	/**
	 * @return ObjectStorage
	 */
	public function getTeaser1Image() {
		if ($this->teaser1Image instanceof LazyLoadingProxy) {
			$this->teaser1Image->_loadRealInstance();
		}

		return $this->teaser1Image;
	}

	/**
	 * @param ObjectStorage $teaser1Images
	 * @return void
	 */
	public function setTeaser1Image(ObjectStorage $teaser1Images) {
		$this->teaser1Image = $teaser1Images;
	}

	/**
	 * @param FileReference $teaser1Image
	 * @return void
	 */
	public function addTeaser1Image(FileReference $teaser1Image) {
		if ($this->teaser1Image instanceof LazyLoadingProxy) {
			$this->teaser1Image->_loadRealInstance();
		}

		$this->teaser1Image->attach($teaser1Image);
	}

	/**
	 * @param FileReference $teaser1Image
	 * @return void
	 */
	public function removeTeaser1Image(FileReference $teaser1Image) {
		if ($this->teaser1Image instanceof LazyLoadingProxy) {
			$this->teaser1Image->_loadRealInstance();
		}

		$this->teaser1Image->detach($teaser1Image);
	}

	/**
	 * @return ObjectStorage
	 */
	public function getTeaser2Image() {
		if ($this->teaser2Image instanceof LazyLoadingProxy) {
			$this->teaser2Image->_loadRealInstance();
		}

		return $this->teaser2Image;
	}

	/**
	 * @param ObjectStorage $teaser2Images
	 * @return void
	 */
	public function setTeaser2Image(ObjectStorage $teaser2Images) {
		$this->teaser2Image = $teaser2Images;
	}

	/**
	 * @param FileReference $teaser2Image
	 * @return void
	 */
	public function addTeaser2Image(FileReference $teaser2Image) {
		if ($this->teaser2Image instanceof LazyLoadingProxy) {
			$this->teaser2Image->_loadRealInstance();
		}

		$this->teaser2Image->attach($teaser2Image);
	}

	/**
	 * @param FileReference $teaser1Image
	 * @return void
	 */
	public function removeTeaser2Image(FileReference $teaser2Image) {
		if ($this->teaser2Image instanceof LazyLoadingProxy) {
			$this->teaser2Image->_loadRealInstance();
		}

		$this->teaser2Image->detach($teaser2Image);
	}

	/**
	 * @param boolean $useImageCrop
	 */
	public function setUseImageCrop($useImageCrop) {
		$this->useImageCrop = ($useImageCrop == TRUE);
	}

	/**
	 * @return boolean
	 */
	public function getUseImageCrop() {
		return $this->useImageCrop;
	}

	/**
	 * @param boolean $useImage2Crop
	 */
	public function setUseImage2Crop($useImage2Crop) {
		$this->useImage2Crop = ($useImage2Crop == TRUE);
	}

	/**
	 * @return boolean
	 */
	public function getUseImage2Crop() {
		return $this->useImage2Crop;
	}

	/**
	 * @return int
	 */
	public function getSorting() {
		return $this->sorting;
	}

	/**
	 * @param int $sorting
	 */
	public function setSorting($sorting) {
		$this->sorting = (int) $sorting;
	}
}

?>
